@@ -64,6 +64,29 @@ def test_multi_lookup_by_name():
     assert u0 == lookup(request)
     assert u1 == lookup(request, name="another")
 
+def test_many_kinds_utility():
+    from pyramid_tiny_utility import ConfiguredObject
+    from pyramid_tiny_utility import create_configured_instance_lookup        
+    class A(ConfiguredObject):
+        pass
+    class B(ConfiguredObject):
+        pass
+
+    lookupA = create_configured_instance_lookup(A)
+    lookupB = create_configured_instance_lookup(B)
+
+    a = A()
+    b = B()
+    _config.add_instance(a)
+    _config.add_instance(b)
+    
+    class request:
+        registry = _config.registry
+
+    assert a == lookupA(request)
+    assert b == lookupB(request)
+    
+
 def test_register_utility_after_set_validation():
     from pyramid_tiny_utility.components import ConfiguredObject
     from pyramid.exceptions import ConfigurationError
@@ -72,17 +95,17 @@ def test_register_utility_after_set_validation():
         def __init__(self, depends=None):
             self.depends = depends
 
-        from_settings = ConfiguredObject.create_from_settings_from_paramters(["depends"])
+        from_settings = ConfiguredObject.create_from_settings_from_paramters(["depends"], prefix="test.")
 
     def assert_depends(o):
         if not o.depends:
             raise ConfigurationError("")
     _config.add_validation(HasValidation, assert_depends)
 
-    settings = {"depends": True}
+    settings = {"test.depends": True}
     _config.add_instance_from_settings(HasValidation, settings)
 
-    settings = {"depends": False}
+    settings = {"test.depends": False}
     with pytest.raises(ConfigurationError):
         _config.add_instance_from_settings(HasValidation, settings)
 
